class Address < ActiveRecord::Base
  before_save :update_geo
  before_save :update_station

  def self.zip2address(zip)
    return [ '', '', '' ] if /^¥d{7}$/ =~ zip
    server = XMLRPC::Client.new('yubin.senmon.net', '/service/xmlrpc/')
    ary = server.call('yubin.fetchAddressByPostcode', zip.gsub('-','')).first
    [ ary["pref"], (ary["city"]||'') + (ary["town"]||""), (ary["address"]||"") + (ary["other"]||"") ]
  rescue
    [ '', '', '' ]
  end

  def stations
    @stations ||= (1..5).collect{ |index|
      next if self["station#{index}_name"].blank?
      [self["station#{index}_name"], self["station#{index}_lng"], self["station#{index}_lat"]]
    }.compact
  end

  private
  def update_geo
    geo = JSON.parse(open("http://maps.google.com/maps/geo?q=%s&output=json&key=%s" % [CGI.escape(self.address1), GOOGLE_APPLICATION_ID]).read)
    self.lng, self.lat = geo["Placemark"].first["Point"]["coordinates"]
  end

  private
  def update_station
    stations = JSON.parse(open("http://express.heartrails.com/api/json?method=getStations&x=%f&y=%f" % [self.lng, self.lat]).read)["response"]["station"]
    # 初期化
    attrs = {}
    (1..5).each do |index|
      attrs["station#{index}_name"] = attrs["station#{index}_lng"] = attrs["station#{index}_lat"] = nil
    end

    index = 1
    stations.each do |station|
      attrs["station#{index}_name"] =  station["line"] + " " + station["name"]
      attrs["station#{index}_lng"] = station["x"]
      attrs["station#{index}_lat"] = station["y"]
      index += 1
    end

    self.attributes = attrs
  end

end
