require File.dirname(__FILE__) + '/../test_helper'

class BookTest < Test::Unit::TestCase
  fixtures :books

	NEW_BOOK = {}	# e.g. {:name => 'Test Book', :description => 'Dummy'}
	REQ_ATTR_NAMES 			 = %w( ) # name of fields that must be present, e.g. %(name description)
	DUPLICATE_ATTR_NAMES = %w( ) # name of fields that cannot be a duplicate, e.g. %(name description)

  def setup
    # Retrieve fixtures via their name
    # @first = books(:first)
  end

  def test_raw_validation
    book = Book.new
    if REQ_ATTR_NAMES.blank?
      assert book.valid?, "Book should be valid without initialisation parameters"
    else
      # If Book has validation, then use the following:
      assert !book.valid?, "Book should not be valid without initialisation parameters"
      REQ_ATTR_NAMES.each {|attr_name| assert book.errors.invalid?(attr_name.to_sym), "Should be an error message for :#{attr_name}"}
    end
  end

	def test_new
    book = Book.new(NEW_BOOK)
    assert book.valid?, "Book should be valid"
   	NEW_BOOK.each do |attr_name|
      assert_equal NEW_BOOK[attr_name], book.attributes[attr_name], "Book.@#{attr_name.to_s} incorrect"
    end
 	end

	def test_validates_presence_of
   	REQ_ATTR_NAMES.each do |attr_name|
			tmp_book = NEW_BOOK.clone
			tmp_book.delete attr_name.to_sym
			book = Book.new(tmp_book)
			assert !book.valid?, "Book should be invalid, as @#{attr_name} is invalid"
    	assert book.errors.invalid?(attr_name.to_sym), "Should be an error message for :#{attr_name}"
    end
 	end

	def test_duplicate
    current_book = Book.find_first
   	DUPLICATE_ATTR_NAMES.each do |attr_name|
   		book = Book.new(NEW_BOOK.merge(attr_name.to_sym => current_book[attr_name]))
			assert !book.valid?, "Book should be invalid, as @#{attr_name} is a duplicate"
    	assert book.errors.invalid?(attr_name.to_sym), "Should be an error message for :#{attr_name}"
		end
	end
end

